==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/LOVCUSTOMFIELD_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LOVCUSTOMFIELD_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LOVCUSTOMFIELD_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSOCIATECUSTOMFIELDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVSEQUENCENO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOOKUPVALUES" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://schemas.datastream.net/MP_fields}MPENTITY_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOVCUSTOMFIELD_Type", propOrder = {
    "associatecustomfieldid",
    "lovsequenceno",
    "lovcode",
    "lookupvalues"
})
public class LOVCUSTOMFIELD_Type {

    @XmlElement(name = "ASSOCIATECUSTOMFIELDID", required = true)
    protected ASSOCIATECUSTFIELD_Type associatecustomfieldid;
    @XmlElement(name = "LOVSEQUENCENO")
    protected Long lovsequenceno;
    @XmlElement(name = "LOVCODE")
    protected String lovcode;
    @XmlElement(name = "LOOKUPVALUES")
    protected String lookupvalues;
    @XmlAttribute(name = "entity")
    protected NOUN_Type entity;

    /**
     * Obtient la valeur de la propriété associatecustomfieldid.
     * 
     * @return
     *     possible object is
     *     {@link ASSOCIATECUSTFIELD_Type }
     *     
     */
    public ASSOCIATECUSTFIELD_Type getASSOCIATECUSTOMFIELDID() {
        return associatecustomfieldid;
    }

    /**
     * Définit la valeur de la propriété associatecustomfieldid.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSOCIATECUSTFIELD_Type }
     *     
     */
    public void setASSOCIATECUSTOMFIELDID(ASSOCIATECUSTFIELD_Type value) {
        this.associatecustomfieldid = value;
    }

    /**
     * Obtient la valeur de la propriété lovsequenceno.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getLOVSEQUENCENO() {
        return lovsequenceno;
    }

    /**
     * Définit la valeur de la propriété lovsequenceno.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setLOVSEQUENCENO(Long value) {
        this.lovsequenceno = value;
    }

    /**
     * Obtient la valeur de la propriété lovcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOVCODE() {
        return lovcode;
    }

    /**
     * Définit la valeur de la propriété lovcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOVCODE(String value) {
        this.lovcode = value;
    }

    /**
     * Obtient la valeur de la propriété lookupvalues.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOOKUPVALUES() {
        return lookupvalues;
    }

    /**
     * Définit la valeur de la propriété lookupvalues.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOOKUPVALUES(String value) {
        this.lookupvalues = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getEntity() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setEntity(NOUN_Type value) {
        this.entity = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/LOVCUSTOMFIELD_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LOVCUSTOMFIELD_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LOVCUSTOMFIELD_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSOCIATECUSTOMFIELDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVSEQUENCENO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOVCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOOKUPVALUES" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://schemas.datastream.net/MP_fields}MPENTITY_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOVCUSTOMFIELD_Type", propOrder = {
    "associatecustomfieldid",
    "lovsequenceno",
    "lovcode",
    "lookupvalues"
})
public class LOVCUSTOMFIELD_Type {

    @XmlElement(name = "ASSOCIATECUSTOMFIELDID", required = true)
    protected ASSOCIATECUSTFIELD_Type associatecustomfieldid;
    @XmlElement(name = "LOVSEQUENCENO")
    protected Long lovsequenceno;
    @XmlElement(name = "LOVCODE")
    protected String lovcode;
    @XmlElement(name = "LOOKUPVALUES")
    protected String lookupvalues;
    @XmlAttribute(name = "entity")
    protected NOUN_Type entity;

    /**
     * Gets the value of the associatecustomfieldid property.
     * 
     * @return
     *     possible object is
     *     {@link ASSOCIATECUSTFIELD_Type }
     *     
     */
    public ASSOCIATECUSTFIELD_Type getASSOCIATECUSTOMFIELDID() {
        return associatecustomfieldid;
    }

    /**
     * Sets the value of the associatecustomfieldid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSOCIATECUSTFIELD_Type }
     *     
     */
    public void setASSOCIATECUSTOMFIELDID(ASSOCIATECUSTFIELD_Type value) {
        this.associatecustomfieldid = value;
    }

    /**
     * Gets the value of the lovsequenceno property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getLOVSEQUENCENO() {
        return lovsequenceno;
    }

    /**
     * Sets the value of the lovsequenceno property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setLOVSEQUENCENO(Long value) {
        this.lovsequenceno = value;
    }

    /**
     * Gets the value of the lovcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOVCODE() {
        return lovcode;
    }

    /**
     * Sets the value of the lovcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOVCODE(String value) {
        this.lovcode = value;
    }

    /**
     * Gets the value of the lookupvalues property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOOKUPVALUES() {
        return lookupvalues;
    }

    /**
     * Sets the value of the lookupvalues property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOOKUPVALUES(String value) {
        this.lookupvalues = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getEntity() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setEntity(NOUN_Type value) {
        this.entity = value;
    }

}
